return {
	"nvim-telescope/telescope.nvim",
	branch = "0.1.x",
	dependencies = {
		"nvim-lua/plenary.nvim",
		{ "nvim-telescope/telescope-fzf-native.nvim", build = "make" },
		"echasnovski/mini.icons",
	},
	config = function()
		local telescope = require("telescope")
		local actions = require("telescope.actions")
		-- local transform_mod = require("telescope.actions.mt").transform_mod

		telescope.setup({
			defaults = {
				path_display = { "smart" },
				mappings = {
					i = {
						["<C-k>"] = actions.move_selection_previous, -- move to prev result
						["<C-j>"] = actions.move_selection_next, -- move to next result
					},
				},
			},
		})

		telescope.load_extension("fzf")

		-- ─< set keymaps >─────────────────────────────────────────────────────────────────────
		local map = vim.keymap.set -- for conciseness
		local builtin = require("telescope.builtin")
		-- ─────────────────────────────────< Telescope mappings >─────────────────────────────────
		map("n", "<leader>T", "<cmd>Telescope colorscheme<CR>")

		map("n", "<leader>ff", "<cmd>Telescope find_files<CR>", { noremap = true, silent = true, desc = "Find Files" })
		-- map("n", "<leader>ff", builtin.find_files, { desc = "Find Files" })
		map("n", "<leader>fw", "<cmd>Telescope live_grep<CR>", { noremap = true, silent = true, desc = "Find Word" })
		-- map("n", "<leader>fw", builtin.live_grep, { desc = "Find word" })
		-- map("n", "<leader>fb", "<cmd>Telescope buffers<CR>", { noremap = true, silent = true, desc = "Find Buffers" })
		map("n", "<leader><leader>", builtin.buffers, { desc = "[ ] Find existing buffers" })
		map("n", "<leader>fn", function()
			builtin.find_files({ cwd = vim.fn.stdpath("config") })
		end, { desc = "Find Neovim files" })
		map("n", "<leader>fh", builtin.help_tags, { desc = "Find Help" })
		map("n", "<leader>fk", builtin.keymaps, { desc = "Find Keymaps" })
		map("n", "<leader>fd", builtin.diagnostics, { desc = "Find Diagnostics" })
		map("n", "<leader>fo", builtin.oldfiles, { desc = "Find old/Recent Files" })

		-- Additional custom mappings
		map("n", "<leader>/", function()
			builtin.current_buffer_fuzzy_find(require("telescope.themes").get_dropdown())
		end, { desc = "Search in current buffer" })
		map("n", "<leader>f/", function()
			builtin.live_grep({ grep_open_files = true, prompt_title = "Live Grep in Open Files" })
		end, { desc = "Search in Open Files" })
	end,
}
